@@ -6,6 +6,8 @@ copyToDialog::copyToDialog(QWidget *parent) :
     ui(new Ui::copyToDialog)
 {
     ui->setupUi(this);
+    ui->copyToDialogBtnBox->addButton("OK", QDialogButtonBox::YesRole);
+    ui->copyToDialogBtnBox->addButton("Cancel", QDialogButtonBox::NoRole);
 }
 
 copyToDialog::~copyToDialog()
