@@ -11,6 +11,10 @@ wpManager::wpManager(QWidget *parent) :
     ui(new Ui::wpManager)
 {
     ui->setupUi(this);
+    ui->manPrevBtn->setStyleSheet("text-align: left");
+    ui->manEditBtn->setStyleSheet("text-align: left");
+    ui->manDelBtn->setStyleSheet("text-align: left");
+    ui->manPrevName->setStyleSheet("color: deepskyblue");
 
     // Set the Images directory as the fixed path, filter on .desktop files
     imageSetDir.setPath("/home/user/MyDocs/.images/");
